typos
diff --git a/Modules/cStringIO.c b/Modules/cStringIO.c
index ac84ab0..7e8874b 100644
--- a/Modules/cStringIO.c
+++ b/Modules/cStringIO.c
@@ -52,7 +52,7 @@
 
 #define IOOOBJECT(O) ((IOobject*)(O))
 
 /* Declarations for objects of type StringO */
 
 typedef struct { /* Subtype of IOobject */
   PyObject_HEAD
@@ -487,7 +487,7 @@
 static PyTypeObject Otype = {
   PyObject_HEAD_INIT(NULL)
   0,	       			/*ob_size*/
-  "cStringIO.StringO",   	/*tp_name*/
+  "cStringIO.StringIO",   	/*tp_name*/
   sizeof(Oobject),       	/*tp_basicsize*/
   0,	       			/*tp_itemsize*/
   /* methods */
@@ -540,7 +540,7 @@
         return (PyObject*)self;
 }
 
 /* End of code for StringO objects */
 /* -------------------------------------------------------- */
 
 static PyObject *
@@ -52,7 +52,7 @@
 #define IOOOBJECT(O) ((IOobject*)(O))
 
-/* Declarations for objects of type StringO */
+/* Declarations for objects of type StringIO */
 
 typedef struct { /* Subtype of IOobject */
@@ -540,7 +540,7 @@
 }
 
-/* End of code for StringO objects */
+/* End of code for StringIO objects */
 /* -------------------------------------------------------- */
 